@@ -108,9 +108,6 @@ void KMouseTool::init_vars()
 	// find the user's autostart directory
 	autostartdirname = KGlobalSettings::autostartPath();
 
-	// SimpleSoundServer server(Reference("global:Arts_SimpleSoundServer"));
-//	sound_server(Reference("global:Arts_SimpleSoundServer"));
-
 	QDesktopWidget *d = QApplication::desktop();
 	int w = d->width();
 	int h = d->height();
@@ -231,28 +228,7 @@ void KMouseTool::playTickSound()
 
 	mplayer->setCurrentSource(mSoundFileName);
 	mplayer->play();
-	// This is a bit slow.
-//	KAudioPlayer::play(mSoundFileName);
-	return;
 
-	// the solution seems to be to use MCOP,
-	// but SimpleSoundServer is not cooperating
-
-	// When using the following code, make sure to link with
-	// Put " -lsoundserver_idl" in the linker options in KDevelop.
-
-//  SimpleSoundServer server = SimpleSoundServer::_fromString("global:Arts_SimpleSoundServer");
-//	SimpleSoundServer *ss = new SimpleSoundServer(Reference("global:Arts_SimpleSoundServer"));
-//	SimpleSoundServer sound_server2(Reference("global:Arts_SimpleSoundServer"));
-
-//	if(sound_server.isNull())
-//		return;
-//	sound_server.play(mSoundFileName.toLatin1());
-
-	// Another approach is to try using QSound.
-	// QSound depends on Network Audio Server, which doesn't seem to work on my Debian Woody system.
-	// I haven't spent much time working on it, though.
-//	QSound::play(mSoundFileName);
 }
 
 KMouseTool::KMouseTool(QWidget *parent, const char *name) :
@@ -493,7 +469,7 @@ void KMouseTool::updateStartStopText()
 	if (mousetool_is_running)
 		buttonStartStop->setText(i18n("&Stop"));
 	else
-		buttonStartStop->setText(i18n("&Start"));
+		buttonStartStop->setText(i18nc("Start tracking the mouse", "&Start"));
 	trayIcon->updateStartStopText(mousetool_is_running);
 }
 
@@ -620,7 +596,7 @@ KMouseToolTray::KMouseToolTray (QWidget *parent, const char *name) : KSystemTray
 {
 	setObjectName(name);
 
-	startStopAct = contextMenu()->addAction (i18n("&Start"), this, SIGNAL(startStopSelected()));
+	startStopAct = contextMenu()->addAction (i18nc("Start tracking the mouse", "&Start"), this, SIGNAL(startStopSelected()));
 	contextMenu()->addSeparator();
         QAction* act;
 	act = contextMenu()->addAction (i18n("&Configure KMouseTool..."), this, SIGNAL(configureSelected()));
@@ -644,7 +620,7 @@ void KMouseToolTray::updateStartStopText(bool mousetool_is_running)
 		icon = KIconLoader::global()->loadIcon("kmousetool_on", KIconLoader::Small);
 	}
 	else {
-                startStopAct->setText(i18n("&Start"));
+                startStopAct->setText(i18nc("Start tracking the mouse", "&Start"));
 		icon = KIconLoader::global()->loadIcon("kmousetool_off", KIconLoader::Small);
 	}
 	setIcon (icon);
