@@ -1,7 +1,7 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
   This file is the template for the configuration plug ins.
   -------------------
-  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández
+  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
   -------------------
   Original author: José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
   Current Maintainer: Gary Cramblitt <garycramblitt@comcast.net>
@@ -11,12 +11,13 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
+ *   the Free Software Foundation; version 2 of the License or             *
+ *   (at your option) version 3.                                           *
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _PLUGINCONF_H_
-#define _PLUGINCONF_H_
+#ifndef PLUGINCONF_H
+#define PLUGINCONF_H
 
 // Qt includes.
 #include <QtGui/QWidget>
@@ -356,7 +357,7 @@ class KDE_EXPORT PlugInConf : public QWidget{
         * is contained in any directory in the PATH, it returns the full path to it.
         * @param name        The name of the file to search for.
         * @returns           The path to the file on success, a blank QString
-        *                    if its not found.
+        *                    if it is not found.
         */
         QString getLocation(const QString &name);
 
@@ -374,4 +375,4 @@ class KDE_EXPORT PlugInConf : public QWidget{
         TestPlayer* m_player;
 };
 
-#endif  //_PLUGINCONF_H_
+#endif  //PLUGINCONF_H
