@@ -21,6 +21,11 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// Epos Plugin includes.
+#include "eposconf.h"
+#include "eposproc.h"
+#include "eposconf.moc"
+
 // C++ includes.
 #include <math.h>
 
@@ -42,11 +47,6 @@
 // KTTS includes.
 #include <testplayer.h>
 
-// Epos Plugin includes.
-#include "eposproc.h"
-#include "eposconf.h"
-#include "eposconf.moc"
-
 /** Constructor */
 EposConf::EposConf( QWidget* parent, const QStringList& /*args*/) :
     PlugInConf(parent, "eposconf")
@@ -285,13 +285,13 @@ void EposConf::slotSynthStopped()
 // with alpha = 1000/(log(200)-log(50))
 
 int EposConf::percentToSlider(int percentValue) {
-    double alpha = 1000 / (log(200) - log(50));
-    return (int)floor (0.5 + alpha * (log(percentValue)-log(50)));
+    double alpha = 1000 / (log(200.0) - log(50.0));
+    return (int)floor (0.5 + alpha * (log((double)percentValue)-log(50.0L)));
 }
 
 int EposConf::sliderToPercent(int sliderValue) {
-    double alpha = 1000 / (log(200) - log(50));
-    return (int)floor(0.5 + exp (sliderValue/alpha + log(50)));
+    double alpha = 1000 / (log(200.0) - log(50.0));
+    return (int)floor(0.5 + exp (sliderValue/alpha + log(50.0)));
 }
 
 void EposConf::timeBox_valueChanged(int percentValue) {
