@@ -21,12 +21,11 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
-#ifndef _FESTIVALINTCONF_H_
-#define _FESTIVALINTCONF_H_
+#ifndef FESTIVALINTCONF_H
+#define FESTIVALINTCONF_H
 
 // Qt includes.
-#include <qstringlist.h>
-#include <qvaluelist.h>
+#include <QtCore/QList>
 
 // KDE includes.
 #include <kconfig.h>
@@ -36,7 +35,7 @@
 #include "pluginconf.h"
 
 // FestivalInt includes.
-#include "festivalintconfwidget.h"
+#include "ui_festivalintconfwidget.h"
 #include "festivalintproc.h"
 
 class KProgressDialog;
@@ -54,12 +53,12 @@ typedef struct voiceStruct{
     bool pitchAdjustable;       // True if the voice supports pitch adjustments.
 } voice;
 
-class FestivalIntConf : public PlugInConf {
+class FestivalIntConf : public PlugInConf, public Ui::FestivalIntConfWidget {
     Q_OBJECT 
 
     public:
         /** Constructor */
-        FestivalIntConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+        explicit FestivalIntConf( QWidget* parent = 0, const QStringList &args = QStringList());
 
         /** Destructor */
         ~FestivalIntConf();
@@ -90,7 +89,7 @@ class FestivalIntConf : public PlugInConf {
         * This function informs the plugin of the desired language to be spoken
         * by the plugin.  The plugin should attempt to adapt itself to the
         * specified language code, choosing sensible defaults if necessary.
-        * If the passed-in code is QString::null, no specific language has
+        * If the passed-in code is QString(), no specific language has
         * been chosen.
         * @param lang        The desired language code or Null if none.
         *
@@ -108,7 +107,7 @@ class FestivalIntConf : public PlugInConf {
         * Return fully-specified talker code for the configured plugin.  This code
         * uniquely identifies the configured instance of the plugin and distinquishes
         * one instance from another.  If the plugin has not been fully configured,
-        * i.e., cannot yet synthesize, return QString::null.
+        * i.e., cannot yet synthesize, return QString().
         * @return            Fully-specified talker code.
         */
         QString getTalkerCode();
@@ -117,9 +116,9 @@ class FestivalIntConf : public PlugInConf {
         /** Scan for the different voices in festivalPath/lib */
         void scanVoices();
         void configChanged(){
-            // kdDebug() << "FestivalIntConf::configChanged: Running" << endl;
+            // kDebug() << "FestivalIntConf::configChanged: Running";
             emit changed(true);
-        };
+        }
         void slotTest_clicked();
         void slotSynthFinished();
         void slotSynthStopped();
@@ -162,15 +161,12 @@ class FestivalIntConf : public PlugInConf {
         */
         void setDefaultVoice(int currentVoiceIndex);
 
-        // Configuration Widget.
-        FestivalIntConfWidget* m_widget;
-
         // Language code.
         QString m_languageCode;
         // Language country code (if any).
         QString m_countryCode;
         // List of voices */
-        QValueList<voice> m_voiceList;
+        QList<voice> m_voiceList;
         // Festival synthesizer.
         FestivalIntProc* m_festProc;
         // Synthesized wave file name.
@@ -184,4 +180,4 @@ class FestivalIntConf : public PlugInConf {
         // Whether Festival supports SSML or not.
         FestivalIntProc::SupportsSSML m_supportsSSML;
 };
-#endif // _FESTIVALINTCONF_H_
+#endif // FESTIVALINTCONF_H
